==> mp-5.0.2.tar.gz: mp-5.0.2/mpsl/y.tab.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NULLV = 258,
     INTEGER = 259,
     REAL = 260,
     STRING = 261,
     SYMBOL = 262,
     LITERAL = 263,
     WHILE = 264,
     IF = 265,
     SUB = 266,
     FOREACH = 267,
     LOCAL = 268,
     BREAK = 269,
     RETURN = 270,
     IFI = 271,
     ELSE = 272,
     BOOLOR = 273,
     BOOLAND = 274,
     IMOD = 275,
     IDIV = 276,
     IMUL = 277,
     ISUB = 278,
     IADD = 279,
     DEC = 280,
     INC = 281,
     RANGE = 282,
     HASHPAIR = 283,
     NUMLE = 284,
     NUMGE = 285,
     NUMNE = 286,
     STRNE = 287,
     NUMEQ = 288,
     STREQ = 289,
     STRCAT = 290,
     BITAND = 291,
     BITXOR = 292,
     BITOR = 293,
     MOD = 294,
     UMINUS = 295
   };
#endif
/* Tokens.  */
#define NULLV 258
#define INTEGER 259
#define REAL 260
#define STRING 261
#define SYMBOL 262
#define LITERAL 263
#define WHILE 264
#define IF 265
#define SUB 266
#define FOREACH 267
#define LOCAL 268
#define BREAK 269
#define RETURN 270
#define IFI 271
#define ELSE 272
#define BOOLOR 273
#define BOOLAND 274
#define IMOD 275
#define IDIV 276
#define IMUL 277
#define ISUB 278
#define IADD 279
#define DEC 280
#define INC 281
#define RANGE 282
#define HASHPAIR 283
#define NUMLE 284
#define NUMGE 285
#define NUMNE 286
#define STRNE 287
#define NUMEQ 288
#define STREQ 289
#define STRCAT 290
#define BITAND 291
#define BITXOR 292
#define BITOR 293
#define MOD 294
#define UMINUS 295




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 88 "mpsl.y"
{
	mpdm_t v;	/* a simple value */
	mpdm_t ins;	/* an 'instruction': [ opcode, args ] */
}
/* Line 1489 of yacc.c.  */
#line 134 "y.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> mp-5.1.3.tar.gz: mp-5.1.3/mpsl/y.tab.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NULLV = 258,
     INTEGER = 259,
     REAL = 260,
     STRING = 261,
     SYMBOL = 262,
     LITERAL = 263,
     WHILE = 264,
     IF = 265,
     SUB = 266,
     FOREACH = 267,
     LOCAL = 268,
     BREAK = 269,
     RETURN = 270,
     IFI = 271,
     ELSE = 272,
     BOOLOR = 273,
     BOOLAND = 274,
     IMOD = 275,
     IDIV = 276,
     IMUL = 277,
     ISUB = 278,
     IADD = 279,
     DEC = 280,
     INC = 281,
     RANGE = 282,
     HASHPAIR = 283,
     NUMLE = 284,
     NUMGE = 285,
     NUMNE = 286,
     STRNE = 287,
     NUMEQ = 288,
     STREQ = 289,
     STRCAT = 290,
     BITAND = 291,
     BITXOR = 292,
     BITOR = 293,
     MOD = 294,
     UMINUS = 295
   };
#endif
/* Tokens.  */
#define NULLV 258
#define INTEGER 259
#define REAL 260
#define STRING 261
#define SYMBOL 262
#define LITERAL 263
#define WHILE 264
#define IF 265
#define SUB 266
#define FOREACH 267
#define LOCAL 268
#define BREAK 269
#define RETURN 270
#define IFI 271
#define ELSE 272
#define BOOLOR 273
#define BOOLAND 274
#define IMOD 275
#define IDIV 276
#define IMUL 277
#define ISUB 278
#define IADD 279
#define DEC 280
#define INC 281
#define RANGE 282
#define HASHPAIR 283
#define NUMLE 284
#define NUMGE 285
#define NUMNE 286
#define STRNE 287
#define NUMEQ 288
#define STREQ 289
#define STRCAT 290
#define BITAND 291
#define BITXOR 292
#define BITOR 293
#define MOD 294
#define UMINUS 295




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 88 "mpsl.y"

	mpdm_t v;	/* a simple value */
	mpdm_t ins;	/* an 'instruction': [ opcode, args ] */



/* Line 1676 of yacc.c  */
#line 139 "y.tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE yylval;
